==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/eventing/v1beta1/EventTypeSpecFluent.java <==
package io.fabric8.knative.eventing.v1beta1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface EventTypeSpecFluent<A extends EventTypeSpecFluent<A>> extends Fluent<A> {


    public String getBroker();
    public A withBroker(String broker);
    public Boolean hasBroker();
    public A withNewBroker(StringBuilder arg1);
    public A withNewBroker(int[] arg1,int arg2,int arg3);
    public A withNewBroker(char[] arg1);
    public A withNewBroker(StringBuffer arg1);
    public A withNewBroker(byte[] arg1,int arg2);
    public A withNewBroker(byte[] arg1);
    public A withNewBroker(char[] arg1,int arg2,int arg3);
    public A withNewBroker(byte[] arg1,int arg2,int arg3);
    public A withNewBroker(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewBroker(String arg1);
    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(int[] arg1,int arg2,int arg3);
    public A withNewDescription(char[] arg1);
    public A withNewDescription(StringBuffer arg1);
    public A withNewDescription(byte[] arg1,int arg2);
    public A withNewDescription(byte[] arg1);
    public A withNewDescription(char[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDescription(String arg1);
    public String getSchema();
    public A withSchema(String schema);
    public Boolean hasSchema();
    public A withNewSchema(StringBuilder arg1);
    public A withNewSchema(int[] arg1,int arg2,int arg3);
    public A withNewSchema(char[] arg1);
    public A withNewSchema(StringBuffer arg1);
    public A withNewSchema(byte[] arg1,int arg2);
    public A withNewSchema(byte[] arg1);
    public A withNewSchema(char[] arg1,int arg2,int arg3);
    public A withNewSchema(byte[] arg1,int arg2,int arg3);
    public A withNewSchema(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSchema(String arg1);
    public String getSchemaData();
    public A withSchemaData(String schemaData);
    public Boolean hasSchemaData();
    public A withNewSchemaData(StringBuilder arg1);
    public A withNewSchemaData(int[] arg1,int arg2,int arg3);
    public A withNewSchemaData(char[] arg1);
    public A withNewSchemaData(StringBuffer arg1);
    public A withNewSchemaData(byte[] arg1,int arg2);
    public A withNewSchemaData(byte[] arg1);
    public A withNewSchemaData(char[] arg1,int arg2,int arg3);
    public A withNewSchemaData(byte[] arg1,int arg2,int arg3);
    public A withNewSchemaData(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSchemaData(String arg1);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(int[] arg1,int arg2,int arg3);
    public A withNewSource(char[] arg1);
    public A withNewSource(StringBuffer arg1);
    public A withNewSource(byte[] arg1,int arg2);
    public A withNewSource(byte[] arg1);
    public A withNewSource(char[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSource(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/v1beta1/EventTypeSpecFluent.java <==
package io.fabric8.knative.eventing.v1beta1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface EventTypeSpecFluent<A extends EventTypeSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getBroker();
    public A withBroker(String broker);
    public Boolean hasBroker();
    public A withNewBroker(StringBuilder arg1);
    public A withNewBroker(int[] arg1,int arg2,int arg3);
    public A withNewBroker(char[] arg1);
    public A withNewBroker(StringBuffer arg1);
    public A withNewBroker(byte[] arg1,int arg2);
    public A withNewBroker(byte[] arg1);
    public A withNewBroker(char[] arg1,int arg2,int arg3);
    public A withNewBroker(byte[] arg1,int arg2,int arg3);
    public A withNewBroker(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewBroker(String arg1);
    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(int[] arg1,int arg2,int arg3);
    public A withNewDescription(char[] arg1);
    public A withNewDescription(StringBuffer arg1);
    public A withNewDescription(byte[] arg1,int arg2);
    public A withNewDescription(byte[] arg1);
    public A withNewDescription(char[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDescription(String arg1);
    public String getSchema();
    public A withSchema(String schema);
    public Boolean hasSchema();
    public A withNewSchema(StringBuilder arg1);
    public A withNewSchema(int[] arg1,int arg2,int arg3);
    public A withNewSchema(char[] arg1);
    public A withNewSchema(StringBuffer arg1);
    public A withNewSchema(byte[] arg1,int arg2);
    public A withNewSchema(byte[] arg1);
    public A withNewSchema(char[] arg1,int arg2,int arg3);
    public A withNewSchema(byte[] arg1,int arg2,int arg3);
    public A withNewSchema(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSchema(String arg1);
    public String getSchemaData();
    public A withSchemaData(String schemaData);
    public Boolean hasSchemaData();
    public A withNewSchemaData(StringBuilder arg1);
    public A withNewSchemaData(int[] arg1,int arg2,int arg3);
    public A withNewSchemaData(char[] arg1);
    public A withNewSchemaData(StringBuffer arg1);
    public A withNewSchemaData(byte[] arg1,int arg2);
    public A withNewSchemaData(byte[] arg1);
    public A withNewSchemaData(char[] arg1,int arg2,int arg3);
    public A withNewSchemaData(byte[] arg1,int arg2,int arg3);
    public A withNewSchemaData(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSchemaData(String arg1);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(int[] arg1,int arg2,int arg3);
    public A withNewSource(char[] arg1);
    public A withNewSource(StringBuffer arg1);
    public A withNewSource(byte[] arg1,int arg2);
    public A withNewSource(byte[] arg1);
    public A withNewSource(char[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSource(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
}
